@@ -6,6 +6,7 @@ import sys
 import warnings
 import weakref
 from json import dumps
+from typing import Any
 
 import dask
 import dask.config
@@ -64,7 +65,7 @@ class Worker(Process):
         dask.distributed.Worker class
     """
 
-    def __init__(
+    def __init__(  # type: ignore[no-untyped-def]
         self,
         scheduler: str,
         address: str,
@@ -208,14 +209,18 @@ class Scheduler(Process):
     """
 
     def __init__(
-        self, address: str, connect_options: dict, kwargs: dict, remote_python=None
+        self,
+        address: str,
+        connect_options: dict,
+        kwargs: dict,
+        remote_python: str | None = None,
     ):
         super().__init__()
 
         self.address = address
         self.kwargs = kwargs
         self.connect_options = connect_options
-        self.remote_python = remote_python
+        self.remote_python = remote_python or sys.executable
 
     async def start(self):
         try:
@@ -246,9 +251,6 @@ class Scheduler(Process):
                     "Scheduler failed to set DASK_INTERNAL_INHERIT_CONFIG variable "
                 )
 
-        if not self.remote_python:
-            self.remote_python = sys.executable
-
         cmd = " ".join(
             [
                 set_env,
@@ -302,8 +304,8 @@ def SSHCluster(
     worker_module: str = "deprecated",
     worker_class: str = "distributed.Nanny",
     remote_python: str | list[str] | None = None,
-    **kwargs,
-):
+    **kwargs: Any,
+) -> SpecCluster:
     """Deploy a Dask cluster using SSH
 
     The SSHCluster function deploys a Dask Scheduler and Workers for you on a
@@ -406,7 +408,7 @@ def SSHCluster(
             "This will be removed in the future"
         )
         kwargs.setdefault("worker_addrs", hosts)
-        return OldSSHCluster(**kwargs)
+        return OldSSHCluster(**kwargs)  # type: ignore
 
     if not hosts:
         raise ValueError(
